import path from 'path';
import process from 'process';
import { defineConfig, loadEnv } from 'vite';
import vue from '@vitejs/plugin-vue';
import AutoImport from 'unplugin-auto-import/vite';
import Components from 'unplugin-vue-components/vite';
// import Icons from 'unplugin-icons/vite';
// import IconsResolver from 'unplugin-icons/resolver';
import { NaiveUiResolver } from 'unplugin-vue-components/resolvers';
import { visualizer } from 'rollup-plugin-visualizer';
import Pages from 'vite-plugin-pages';
import Layouts from 'vite-plugin-vue-layouts';
import vueI18n from '@intlify/vite-plugin-vue-i18n';
import { cliDir, appDir, srcDir } from './config.js';

// import Unocss from 'unocss/vite';
// import * as yicodePaths from '../paths.js';
// import * as yicodeUtils from '../utils.js';
// import {
//     //
//     presetUno,
//     presetMini,
//     presetWind,
//     presetAttributify,
//     presetIcons,
//     presetWebFonts,
//     presetTypography
// } from 'unocss';

// TODO: 完成图标使用方案

export default defineConfig(({ command, mode }) => {
    const env = loadEnv(process.env['NODE_ENV_FILE'], path.resolve(process.cwd(), 'src', 'env'), 'YICODE_');
    return {
        plugins: [
            //
            vue({
                reactivityTransform: true
            }),
            AutoImport({
                include: [/\.[tj]sx?$/, /\.vue$/, /\.vue\?vue/, /\.md$/],
                imports: ['vue', '@vueuse/core'],
                dirs: [
                    //
                    path.resolve(srcDir, 'components'),
                    path.resolve(srcDir, 'hooks')
                ],
                vueTemplate: true,
                dts: '.cache/auto-imports.d.ts'
            }),
            Components({
                directoryAsNamespace: true,
                resolvers: [
                    //
                    // IconsResolver(),
                    NaiveUiResolver()
                ]
            }),
            // 页面路由
            Pages.default({
                routeStyle: 'nuxt',
                dirs: path.resolve(srcDir, 'pages')
            }),
            // 框架
            Layouts.default(),
            vueI18n({
                include: path.resolve(srcDir, 'i18n/**')
            }),
            visualizer({
                open: false,
                brotliSize: true,
                filename: '.cache/buildReport.html'
            })
        ],
        css: {
            preprocessorOptions: {
                scss: {
                    additionalData: `@use "@/styles/variable.scss" as *;`
                }
            }
        },
        resolve: {
            alias: [
                {
                    find: '@',
                    replacement: path.resolve(srcDir)
                }
            ]
        },
        envDir: path.resolve(srcDir, 'env'),
        envPrefix: 'yivite',
        build: {
            rollupOptions: {
                plugins: []
            }
        },
        server: {
            port: 8000
        }
    };
});
